@@ -25,6 +25,8 @@ class PostSummaryTweet:
 
     def tweet(self, days: int = 7) -> None:
         tweet_log = os.path.join(self.summary_tweet_log_path, "summary_tweet.log")
+        os.makedirs(self.summary_tweet_log_path, exist_ok=True)
+        open(tweet_log, "a").close()
         week_data_paths = [
             os.path.join(
                 self.source_path,
@@ -32,6 +34,9 @@ class PostSummaryTweet:
             )
             for i in range(days)
         ][::-1]
+        for i in week_data_paths:
+            if not os.path.isfile(i):
+                print("[]", file=open(i, "w"))
         week_book_count = [
             (
                 i.split("/")[-1].replace(".json", "", 1),
@@ -62,16 +67,7 @@ class PostSummaryTweet:
         try:
             status = api.update_status(content)
             return (True, status)
-        except (
-            tweepy.errors.BadRequest,
-            tweepy.errors.TweepyException,
-            tweepy.errors.Forbidden,
-            tweepy.errors.TwitterServerError,
-            tweepy.errors.HTTPException,
-            tweepy.errors.Unauthorized,
-            tweepy.errors.NotFound,
-            tweepy.errors.TooManyRequests,
-        ) as e:
+        except tweepy.TweepyException as e:
             print(content, file=sys.stderr)
             return (False, e)
 
