@@ -22,6 +22,8 @@ class PostTweet:
 
     def tweet(self, data: List[BookData]) -> None:
         tweet_log = os.path.join(self.tweet_log_path, "tweet.log")
+        os.makedirs(self.tweet_log_path, exist_ok=True)
+        open(tweet_log, "a").close()
         tweeted_links = open(tweet_log, "r").readlines()
         target_data = [
             datam for datam in data if datam["data"]["link"] + "\n" not in tweeted_links
@@ -43,9 +45,7 @@ class PostTweet:
                 print(f'[success]{datam["data"]["link"]}, {detail.id}')
                 print(datam["data"]["link"], file=log)
             else:
-                print(
-                    f'[error]{datam["data"]["link"]}, {detail.reason}', file=sys.stderr
-                )
+                print(f'[error]{datam["data"]["link"]}', file=sys.stderr)
 
             time.sleep(40)
         else:
@@ -69,7 +69,7 @@ class PostTweet:
                 )
                 status = api.update_status(content, media_ids=[result_img.media_id])
             return (True, status)
-        except tweepy.TweepError as e:
+        except tweepy.TweepyException as e:
             print(content, file=sys.stderr)
             return (False, e)
 
